@@ -195,7 +195,7 @@ static void compass_draw(GtkWidget *widget, cache_context_t *context) {
     GdkPoint arrow[4];
 
     pos_t *pos = gps_get_pos(context->appdata);
-    if(pos) {
+    if(pos && !isnan(pos->lat) && !isnan(pos->lon)) {
       context->appdata->gps = *pos;   /* save position */
 
       float arot =
@@ -420,7 +420,8 @@ static gboolean goto_update(gpointer data) {
   }
 
   pos_t *pos = gps_get_pos(context->appdata);
-  if(pos) {
+  if(pos && !isnan(pos->lat) && !isnan(pos->lon) &&
+     !isnan(context->gotoc.pos.lat) && !isnan(context->gotoc.pos.lon)) {
     char str[16];
     gpx_pos_get_distance_str(str, sizeof(str), 
 			     *pos, context->gotoc.pos, 
