@@ -210,7 +210,8 @@ GtkWidget *icon_get_widget(int type, int num) {
 }
 
 GdkPixbuf *icon_bearing(pos_t from, pos_t to) {
-  if(isnan(from.lat) && isnan(from.lon))
+  if(isnan(from.lat) || isnan(from.lon) || 
+     isnan(to.lat) || isnan(to.lon))
     return icon_get(ICON_HEADING, 8);
 
   int idx = (gpx_pos_get_bearing(from, to)+22.5)/45.0;
