@@ -202,6 +202,12 @@ void cachelist_view_onRowActivated(GtkTreeView        *treeview,
   GtkTreeIter   iter;
   GtkTreeModel *model = gtk_tree_view_get_model(treeview);
 
+#ifdef USE_MAEMO
+  /* check if a cache is already selected and ignore click if yes */
+  /* (was probably a double click) */
+  if(appdata->cur_cache) return;
+#endif
+
   if(gtk_tree_model_get_iter(model, &iter, path)) {
     cache_t *cache;
     gtk_tree_model_get(model, &iter, CACHELIST_COL_DATA, &cache, -1);
@@ -713,6 +719,12 @@ static void gpxlist_view_onRowActivated(GtkTreeView *treeview,
   GtkTreeIter   iter;
   GtkTreeModel *model = gtk_tree_view_get_model(treeview);
   
+#ifdef USE_MAEMO
+  /* check if a cache is already selected and ignore click if yes */
+  /* (was probably a double click) */
+  if(appdata->cur_gpx) return;
+#endif
+
   if (gtk_tree_model_get_iter(model, &iter, path)) {
     gpx_t *gpx;
     gtk_tree_model_get(model, &iter, GPXLIST_COL_DATA, &gpx, -1);
@@ -1433,7 +1445,7 @@ cb_menu_search(GtkWidget *window, gpointer data) {
     gtk_widget_destroy(dialog);
 }
 
-void on_window_destroy (GtkWidget *widget, gpointer data);
+static void on_window_destroy (GtkWidget *widget, gpointer data);
 
 #ifndef USE_MAEMO
 static void 
@@ -1637,10 +1649,6 @@ void on_export_clicked(GtkButton *button, appdata_t *appdata) {
 }
 
 static const menu_entry_t submenu_tools_entries[] = {
-#ifdef ENABLE_OSM_GPS_MAP
-  { "Map",              "Display an interactive world map", 
-    G_CALLBACK(cb_menu_map) },
-#endif
   { "Geomath",          "Geocoordinate calculation", 
     G_CALLBACK(cb_menu_geomath) },
   { "Geotext",          "Text analysis",             
@@ -1688,9 +1696,7 @@ HildonAppMenu *menu_create(appdata_t *appdata, int mode) {
     g_signal_connect_after(button, "clicked", 
 			   G_CALLBACK(cb_menu_adddir), appdata);
     hildon_app_menu_append(menu, GTK_BUTTON(button));
-  }
 
-  if(mode == MENU_GPXLIST) {
     button = gtk_button_new_with_label(_("Export"));
     g_signal_connect_after(button, "clicked", 
 			   G_CALLBACK(on_export_clicked), appdata);
@@ -1707,6 +1713,15 @@ HildonAppMenu *menu_create(appdata_t *appdata, int mode) {
 			 G_CALLBACK(on_tools_clicked), appdata);
   hildon_app_menu_append(menu, GTK_BUTTON(button));
 
+#ifdef ENABLE_OSM_GPS_MAP
+  if((mode == MENU_GPXLIST) || (mode == MENU_CACHELIST)) {
+    button = gtk_button_new_with_label(_("Map"));
+    g_signal_connect_after(button, "clicked", 
+			   G_CALLBACK(cb_menu_map), appdata);
+    hildon_app_menu_append(menu, GTK_BUTTON(button));
+  }
+#endif
+
 #ifdef HILDON_HELP
   button = gtk_button_new_with_label(_("Help"));
   g_signal_connect_after(button, "clicked", 
@@ -1923,7 +1938,7 @@ void cleanup(appdata_t *appdata) {
   puts("everything is gone");
 }
 
-void on_window_destroy (GtkWidget *widget, gpointer data) {
+static void on_window_destroy (GtkWidget *widget, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
 
   gconf_save_state(appdata);
